@@ -15,7 +15,7 @@ def clean_dict(a, tr=None):
     for key in a.keys():
         if a[key] is None:
             a.pop(key)
-        if tr:
+        elif tr:
             a[key] = tr.get(str(a[key]), a[key])
     return a
 
