@@ -76,7 +76,7 @@ All View classes don't need as_view() and can be created directly from urls.
 __all__ = ('get_url', 'CategoryListView', 'CategoryFeed')
 
 from django.contrib.syndication.views import Feed
-from django.views.generic import CreateView, DetailView, FormView
+from django.views.generic import CreateView, DetailView, FormView, ListView
 from django.views.generic.base import TemplateView as View, View as BaseView
 from django.core.urlresolvers import reverse, get_resolver
 from django.shortcuts import get_object_or_404, redirect
@@ -119,8 +119,12 @@ class AllCategory(object):
     """A simple object for 'All' Menu Item"""
     value = None
 
+    @property
+    def name(self):
+        return _("All")
+
     def __str__(self):
-        return "All" # XXX i18n
+        return "All"
 
 class Category(list):
     """A menu of items in this category, created by ListView"""
@@ -174,15 +178,19 @@ class CategoryListView(View):
 
         filters.update(clean_dict(dict(self.get_opts())))
         filters.update(kwargs)
-        return queryset.filter(**clean_dict(filters, {'True':True,'False':False}))
+        qs = queryset.filter(**clean_dict(filters, {'True':True,'False':False}))
+        try:
+            return qs.order_by(self.get_value('order'))
+        except:
+            return qs
 
     def get_url(self, cid=None, value=None, view=None, exclude=None):
         kwargs = self.kwargs.copy()
         gets = self.request.GET.copy()
         view = view or self.request.resolver_match.url_name
         if cid is not None:
-            args = self.get_possible_args(view)
-            target = cid in args and kwargs or gets
+            args = list(self.get_possible_args(view))
+            target = kwargs if cid in args else gets
             if value is None:
                 target.pop(cid, None)
             else:
@@ -276,7 +284,7 @@ class CategoryListView(View):
         elif model:
             qs = model.objects.all()
         else:
-            raise KeyError(("The field '%s' isn't a ForeignKey, please add"
+            raise KeyError(("The field '%s' isn't a ForeignKey, please add "
                            "the linked model for this category.") % cid)
         return Category(self, qs, cid, name)
 
